@@ -157,7 +157,7 @@ def execute(
                                            tag=tag,
                                            use_cached=use_cached,
                                            parameters_file=parameters_file)
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.pipeline
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.CHAINED.value
 
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
 
@@ -219,7 +219,7 @@ def execute_single_step(
                                            tag=tag,
                                            use_cached='',
                                            parameters_file=parameters_file)
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.pipeline
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.CHAINED.value
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
     try:
         _ = mode_executor.dag.get_node_by_name(step_name)
@@ -287,7 +287,7 @@ def execute_single_node(
                                            tag=tag,
                                            use_cached='',
                                            parameters_file=parameters_file)
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.pipeline
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.CHAINED.value
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
 
     mode_executor.prepare_for_node_execution()
@@ -336,7 +336,7 @@ def execute_single_brach(
                                            run_id=run_id,
                                            tag=tag,
                                            use_cached='')
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.pipeline
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.CHAINED.value
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
 
     branch_internal_name = nodes.BaseNode._get_internal_name_from_command_name(branch_name)
@@ -371,11 +371,9 @@ def execute_notebook(
         tag=tag,
         parameters_file=parameters_file)
 
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.notebook
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.UNCHAINED.value
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
 
-    # Prepare the graph with a single node
-    dag = graph.Graph(start_at='executing notebook')
     step_config = {
         'command': notebook_file,
         'command_type': 'notebook',
@@ -383,17 +381,13 @@ def execute_notebook(
         'next': 'success',
         'catalog': catalog_config,
     }
-    node = graph.create_node(name=f'executing notebook', step_config=step_config)
+    node = graph.create_node(name=f'executing job', step_config=step_config)
 
-    dag.add_node(node)
-    dag.add_terminal_nodes()
-
-    mode_executor.dag = dag
     # Prepare for graph execution
     mode_executor.prepare_for_graph_execution()
 
-    logger.info('Executing the graph')
-    mode_executor.execute_graph(dag=mode_executor.dag)
+    logger.info('Executing the job')
+    mode_executor.execute_job(node=node)
 
     mode_executor.send_return_code()
 
@@ -418,11 +412,10 @@ def execute_function(
         tag=tag,
         parameters_file=parameters_file)
 
-    mode_executor.execution_plan = defaults.EXECUTION_PLAN.function
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.UNCHAINED.value
     utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
 
     # Prepare the graph with a single node
-    dag = graph.Graph(start_at='executing function')
     step_config = {
         'command': command,
         'command_type': 'python',
@@ -430,16 +423,45 @@ def execute_function(
         'next': 'success',
         'catalog': catalog_config,
     }
-    node = graph.create_node(name=f'executing function', step_config=step_config)
+    node = graph.create_node(name=f'executing job', step_config=step_config)
 
-    dag.add_node(node)
-    dag.add_terminal_nodes()
-
-    mode_executor.dag = dag
     # Prepare for graph execution
     mode_executor.prepare_for_graph_execution()
 
-    logger.info('Executing the graph')
-    mode_executor.execute_graph(dag=mode_executor.dag)
+    logger.info('Executing the job')
+    mode_executor.execute_job(node=node)
+
+    mode_executor.send_return_code()
+
+
+def execute_nb_or_func(run_id, command: str, catalog_config: dict,  configuration_file: str,
+                       parameters_file: str = "", tag: str = ""):
+    mode_executor = prepare_configurations(
+        configuration_file=configuration_file,
+        run_id=run_id,
+        tag=tag,
+        parameters_file=parameters_file)
+
+    mode_executor.execution_plan = defaults.EXECUTION_PLAN.UNCHAINED.value
+    utils.set_magnus_environment_variables(run_id=run_id, configuration_file=configuration_file, tag=tag)
+
+    command_type = "python"
+    if command.endswith(".ipynb"):
+        command_type = "notebook"
+
+    step_config = {
+        'command': command,
+        'command_type': command_type,
+        'type': 'task',
+        'next': 'success',
+        'catalog': catalog_config,
+    }
+    node = graph.create_node(name=f'executing job', step_config=step_config)
+
+    # Prepare for graph execution
+    mode_executor.prepare_for_node_execution()
+
+    logger.info('Executing the job')
+    mode_executor.execute_node(node=node)
 
     mode_executor.send_return_code()
